# SEPModules

[![Publish to PyPI](https://github.com/SEOriginal/SEPModules/actions/workflows/python-publish.yml/badge.svg)](https://github.com/SEOriginal/SEPModules/actions/workflows/python-publish.yml) 
|  [Documentation](https://seoriginal.github.io/SEPModules/)

Python package providing basic modules and functionality for various common tasks.

---

The package includes four base modules:
- ### SEPMaths
  For mathematical operations, helper functions, and classes.

- ### SEPIO
  Aids in IO tasks such as reading console line arguments and parameters.

- ### SEPDecorators
  Contains miscellaneous function decorators.

- ### SEPPrinting
  Provides easy and quick implementations of console UI elements like graphs and progress bars, and colored console printing.
